def show():
    code = """import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sns
import warnings
warnings.filterwarnings('ignore')
import sklearn
from sklearn import tree
from sklearn.tree import DecisionTreeClassifier
from sklearn.model_selection import train_test_split
from sklearn.metrics import accuracy_score,confusion_matrix,classification_report
patient_df=pd.read_csv("/content/kidney_disease.csv")
predictors=['rc','sc','pcv','sg','hemo']
target='diagnosis'
print(patient_df)
patient_df.sc.fillna(patient_df.sc.median(),inplace=True)
patient_df.hemo.fillna(patient_df.hemo.median(),inplace=True)
patient_df.rc.fillna(patient_df.rc.median(),inplace=True)
patient_df.pcv.fillna(patient_df.pcv.median(),inplace=True)
patient_df.sg.fillna(patient_df.sg.median(),inplace=True)
patient_df.describe()
plt.figure(figsize=(4,7))
sns.heatmap(patient_df.isna())
plt.show()
Xs=patient_df[predictors]
y=patient_df[target]
plt.figure(figsize=(15,15))
tree.plot_tree(classTree,feature_names=predictors,class_names=y.unique(),filled=True,impurity=False)
plt.show()
plt.figure(figsize=(16,10))
tree.plot_tree(classTree,feature_names=Xs.columns,class_names=[str(c) for c in y.unique()],filled=True,rounded=True)
plt.show()
#Get importance scores from the trained tree
importances=classTree.feature_importances_
#Create Dataframe
feat_imp=pd.DataFrame({'Feature':Xs.columns,'Importance':importances}).sort_values(by='Importance',ascending=False)
#Plot
plt.figure(figsize=(10,6))
plt.barh(feat_imp['Feature'],feat_imp['Importance'])
plt.gca().invert_yaxis()
plt.xlabel('Importance Score')
plt.title('Feature Importances from Decision Tree')
plt.show()
from sklearn.metrics import accuracy_score,confusion_matrix,classification_report
#Predictions on training or test data
y_pred=classTree.predict(Xs)
#Accuracy
print('Accuracy:',accuracy_score(y,y_pred))
#Confusion Matrix
print('Confusion Matrix:\n',confusion_matrix(y,y_pred))
#Precision, Recall, F1-Score
print('Classification Report:\n',classification_report(y,y_pred))
# Question 2
customer_loan = pd.read_csv("/content/CustomerLoan.csv")
print(customer_loan)
customer_loan.head()
customer_loan.isna().sum()
customer_loan.drop(columns=['Name'],inplace=True)
customer_loan
predictors=['income','score']
target='default'
Xs=customer_loan[predictors].drop(index=[20])
y=customer_loan[target].drop(index=[20])
classTree=DecisionTreeClassifier()
classTree.fit(Xs,y)
plt.figure(figsize=(15,15))
tree.plot_tree(classTree,feature_names=predictors,class_names=y.unique(),filled=True,impurity=False)
plt.show()
from sklearn.metrics import accuracy_score,confusion_matrix,classification_report
#Predictions on training or test data
y_pred=classTree.predict(Xs)
#Accuracy
print('Accuracy:',accuracy_score(y,y_pred))
#Confusion Matrix
print('Confusion Matrix:\n',confusion_matrix(y,y_pred))
#Precision, Recall, F1-Score
print('Classification Report:\n',classification_report(y,y_pred))
# Question 3
Churn_data = pd.read_csv("C:/Users/nmims.student/Downloads/Customer Churn.csv")
Churn_data.describe()
Churn_data.isna().sum()
Churn_data['Churn_New'] = np.where(churn_data['Churn'] == 0, "No Churn", "Churn")
predictors = Churn_data.drop(columns = ['Churn','Churn_New']).columns.tolist()
target = 'Churn_New'
X = Churn_data[predictors]
y = Churn_data[target]
Churn_Tree = DecisionTreeClassifier(max_depth=4)
Churn_Tree.fit(X,y)
plt.figure(figsize=(15,15))
plot_tree(Churn_Tree,
          feature_names=predictors,
          class_names=y.unique(),
          filled=True,
          rounded=True,
          impurity=False)
plt.show()
plt.figure(figsize=(16,10))
plot_tree(Churn_Tree,
          feature_names=predictors,
          class_names=y.unique(),
          filled=True,
          rounded=True)
plt.show()
# Predictions on entire data
y_pred = Churn_Tree.predict(X)
print("Accuracy: ", accuracy_score(y,y_pred))
print("Confusion Matrix \n: ", confusion_matrix(y,y_pred))
print("Classification report \n: ", classification_report(y,y_pred))
# Split the data into training and testing set
X_train,X_test,y_train,y_test = train_test_split(X,y,test_size=0.3,random_state=4)
bagging_model = BaggingClassifier(estimator=Churn_Tree,n_estimators=10,random_state=4)
# Train the bagging model
bagging_model.fit(X_train,y_train)
# Make predictions on the test set
y_pred = bagging_model.predict(X_test)
# Evaluate model accuracy
accuracy = accuracy_score(y_test,y_pred)
print(f"Bagging Classifier Accuracy: {accuracy:.4f}")"""
    print(code)




def show():
    code = """
import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns
from sklearn.linear_model import LinearRegression
from sklearn.metrics import r2_score

### a) Read the data into the car_df pandas dataframe
car_df=pd.read_csv(r'C:\Users\nmims.student\Desktop\Abhishek Pracs\IMLT-Practical 2-Datasets\ToyotaCorolla_preprocessed.csv')

print(car_df)

### b) Using data visualization show the relationship mbetween the attribute price and rest of the attributes
car_df.hist()
plt.tight_layout()
plt.show()

X=['Age','Milage_KM','Quarterly_Tax','Weight','Fuel_Type_CNG','Fuel_Type_Diesel','Fuel_Type_Petrol']
y='Price'

df=pd.DataFrame(car_df)
print(df)

# Choose the variable to plot against all others
target_variable='Price'

# Get a list of all other numerical columns
other_variables=[col for col in df.columns if col != target_variable and pd.api.types.is_numeric_dtype(df[col])]
print(other_variables)

# Create scatter plots for the target variable against each other variable
for other_var in other_variables:
    plt.figure(figsize=(3,3)) #Create a new figure for each plot
    sns.scatterplot(x=df[target_variable],y=df[other_var])
    plt.title(f'Scatter Plot of {y} vs {other_var}')
    plt.xlabel('Price')
    plt.ylabel(other_var)
    plt.grid(True)
    plt.show()

sns.pairplot(df,x_vars=other_variables[0:4],y_vars=[target_variable],kind='scatter')
sns.pairplot(df,x_vars=other_variables[4:7],y_vars=[target_variable],kind='scatter')
plt.suptitle(f'Scatter Plots of {target_variable} vs. Other Variables',y=1.02)
plt.tight_layout()
plt.show()

print(other_variables[3:7])
df.plot(kind='density',subplots=True,layout=(3,3),sharex=False)
#sharex shares common X axis for all the graphs
plt.tight_layout()
plt.show()

df.hist()
plt.tight_layout()
plt.show()


### C) Use the visuals in  b) to describe the relationship
# of each attributes

### d)
correlations=df.corr()
print(correlations)
sns.heatmap(correlations,annot=True)
plt.show()

### f)
data_X=car_df[X]
data_y=car_df[y]

lm=LinearRegression()
lm.fit(data_X,data_y)

print('intercept (b0)',lm.intercept_)
coef_names=['b1','b2','b3','b4','b5','b6','b7']
print(pd.DataFrame({'Predictor':data_X.columns,'coefficient Name':coef_names}))

y_pred=lm.predict(data_X)
print(y_pred)
#Calculate R_squared using R2_score
r2=r2_score(data_y,y_pred) #Calculates the R-squared values
print(f'R-squared: {r2}')

#### Residual Analysis ####

### Residual Plots
residuals=data_y -y_pred
print(residuals)
x=np.arange(0,len(data_y))
sns.scatterplot(x=x,y=residuals,color='purple')
plt.axhline(y=0,color='blue',linestyle='--',linewidth=2)
plt.title("Residual plot")
plt.xlabel('Observation number')
plt.ylabel("Residuals")
plt.show()

# Residual vs Fitted Values plot
plt.figure(figsize=(8, 6)) #
sns.scatterplot(x=y_pred, y=residuals, alpha=0.6) #
plt.axhline(y=0, color='red', linestyle='--') # 
plt.xlabel("Fitted Values", fontsize=12) #
plt.ylabel("Residuals", fontsize=12) #
plt.title("Residuals vs. Fitted Values Plot", fontsize=14) #
plt.grid(True, linestyle='--', alpha=0.7) #
plt.show() #


import statsmodels.api as sm

# Normal Q-Q plot
plt.figure(figsize=(8, 6)) #
sm.qqplot(residuals, line='s') #
plt.title("Normal Q-Q Plot of Residuals", fontsize=14) #
plt.grid(True, linestyle='--', alpha=0.7) #
plt.show() #

# Residuals vs Independent Variable plot
plt.figure(figsize=(8, 6)) #
for x in X:
    sns.scatterplot(x=df[x], y=residuals, alpha=0.6) #
    plt.axhline(y=0, color='red', linestyle='--') #
    plt.xlabel(f"Independent Variable {x}", fontsize=12) #
    plt.ylabel("Residuals", fontsize=12) #
    plt.title(f"Residuals vs. Independent Variable {x} Plot", fontsize=14) #
    plt.grid(True, linestyle='--', alpha=0.7) #
    plt.show() #
    
#### Predict for new values ####

newData = pd.DataFrame({'Age':74, 'Milage_KM':124057,'Quarterly_Tax':69, 'Weight':1050, 'Fuel_Type_CNG':0, 'Fuel_Type_Diesel':0, 'Fuel_Type_Petrol':1},index=[1])
newData

predictions = lm.predict(newData)
print("Predicted price with given details:", np.round(predictions,4))

# Q2) The kidney_disease.csv dataset is used to classify between the cases of chronic kidney disease (CKD) 
# and those cases that are not CKD. The dataset shows the data of 400 patients and has 5 independent 
# attributes—namely, red blood cells (rc), serum creatinine (sc), packed cell volume (pcv), specific gravity (sg), 
# and hemoglobin (hemo). Of course, the dataset also has a dependent attribute named diagnosis whereby the patients 
# are labeled with either CKD or not CKD. Fit a logistic regression model and evaluate the performance.

import pandas as pd
import matplotlib.pyplot as plt
from sklearn.linear_model import LogisticRegression
from sklearn.metrics import confusion_matrix

patient_df = pd.read_csv('C:\\Users\\Leena\\OneDrive - Shri Vile Parle Kelavani Mandal\\Leena-April18,2022\\M.Sc. ASA\\Assignments\\SC V\\2025\\IMLT-Practical 2-Datasets\\kidney_disease.csv')
predictors = ['rc', 'sc', 'pcv', 'sg', 'hemo']
target = 'diagnosis'
print(patient_df)

## Fill the missing values with median ##

patient_df.sc.fillna(patient_df.sc.median(),inplace=True)
patient_df.rc.fillna(patient_df.rc.mean(),inplace=True)
patient_df.pcv.fillna(patient_df.pcv.mean(),inplace=True)
patient_df.sg.fillna(patient_df.sg.mean(),inplace=True)
patient_df.hemo.fillna(patient_df.hemo.mean(),inplace=True)
patient_df.describe()

model = LogisticRegression(max_iter=1000)
model.fit(patient_df[predictors], patient_df[target])  

predicted = model.predict(patient_df[predictors])  
matrix = confusion_matrix(patient_df[target], predicted)
print(matrix)
patient_df.describe()


from sklearn.metrics import accuracy_score, confusion_matrix, classification_report

# Accuracy score
acc = accuracy_score(patient_df[target], predicted)
print("Accuracy:", acc)

# Confusion matrix
cm = confusion_matrix(patient_df[target], predicted)
print("Confusion Matrix:\n", cm)

# Detailed report (precision, recall, f1-score)
print("Classification Report:\n", classification_report(patient_df[target], predicted))


from sklearn.model_selection import train_test_split

# Splitting the data into train and test

X_train, X_test, Y_train, Y_test = train_test_split(patient_df[predictors], patient_df[target], test_size=0.2, random_state=42)
print(patient_df[predictors])
print(patient_df[target])
print("80% =len(X_train) = ",   len(X_train) )
print("20% =len(X_test)  = ",   len(X_test)  )
print("80% =len(Y_train) = ",   len(Y_train) )
print("20% =len(Y_test)  = ",   len(Y_test)  )


patient_df[target].value_counts()
Y_train.value_counts()
Y_test.value_counts()


model = LogisticRegression(max_iter=1000)
model.fit(X_train, Y_train)  

predicted = model.predict(X_test)  
matrix = confusion_matrix(Y_test, predicted)
print(matrix)
patient_df.describe()


from sklearn.metrics import accuracy_score, confusion_matrix, classification_report

# Accuracy score
acc = accuracy_score(Y_test, predicted)
print("Accuracy:", acc)

# Confusion matrix
cm = confusion_matrix(Y_test, predicted)
print("Confusion Matrix:\n", cm)

# Detailed report (precision, recall, f1-score)
print("Classification Report:\n", classification_report(Y_test, predicted))


# Accuracy score in the training data 
predicted = model.predict(X_train)  
acc = accuracy_score(Y_train, predicted)
print("Accuracy:", acc)

# Confusion matrix
cm = confusion_matrix(Y_train, predicted)
print("Confusion Matrix:\n", cm)

# Detailed report (precision, recall, f1-score)
print("Classification Report:\n", classification_report(Y_train, predicted))
"""
    print(code)


def show():
    code = """Question 1
import os
import pandas as pd
import matplotlib.pyplot as plt
import numpy as np
path=r'C:\Users\nmims.student\Desktop\Abhishek Pracs\IMLT\Data'
data=pd.read_csv(path+'\\yob1880.txt',names=['Name','Gender','Birth'],header=None)
data.groupby('Gender')['Birth'].sum()

#Question 2
years=range(1880,2018)
pieces=[]
columns=['Name','Gender','Birth']
for year in years:
    path='C:\\Users\\nmims.student\\Desktop\\Abhishek Pracs\\IMLT\\Data\\yob%d.txt'%year
    frame=pd.read_csv(path,names=columns)
    frame['Year']=year
    pieces.append(frame)

#Concatenate everything into a single dataframe
names=pd.concat(pieces,ignore_index=True)

#Question 3
total_births=names.pivot_table('Birth',index='Year',columns='Gender',aggfunc=sum)
print(total_births)
total_births.plot(title='Total births by gender and year')
plt.show()

#Question 4
total_births=names.pivot_table('Birth',index='Year',columns='Name',aggfunc=sum)
names['prop']=names['Birth']/names['Birth'].sum()
names.head()

#Question 5
top1000=names.nlargest(1000,['prop'])
print(top1000)

#Question 6
subset = total_births[['John', 'Harry', 'Mary', 'Marilyn']]
subset
subset.plot(subplots=True, figsize=(12, 10), grid=False,title="Number of births per year")

#Question 7

# uniquenames= names['Name'].unique().sum()
# len(uniquenames)
# uniquenames[:]

# df = boysfromnames[boysfromnames.year == 2010]
# df1 = boysfromnames[boysfromnames.year == 1900]

# popularity= df.sort_values(by='prop', ascending=False)
# popularity.head(int(len(popularity)/2))


# popularity1= df1.sort_values(by='prop', ascending=False)
# popularity1.head(int(len(popularity1)/2))
"""
    print(code)